@@ -29,6 +29,6 @@ class Raw(IPlugin):
             else:
                 mensaje = "Solo puede usar la directiva raw con archivos de texto."
 
-            return utils.mostrar_pagina("<PRE>%s</PRE>" %(mensaje), "Hola")
+            return utils.mostrar_pagina("<PRE>%s</PRE>" %(mensaje), nombre)
         else:
             return utils.mostrar_pagina("Tiene que indicar un archivo a ver en la URL.", "error");
